<?php
// -----------------------------------------------------------------------
//
// $Id: medias.php 104 2012-03-22 10:51:13Z raoul $
//
// Copyright (C) 2003-2012 Raoul Proena
// License: GNU GPL version 3 (see copying.txt file)
// Website: http://www.gnew.fr/
//
// -----------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// -----------------------------------------------------------------------

include('./../includes/common.php');

page_header($lang['ADMIN_MEDIAS_TITLE']);

// Moderator ?
if ($users['user_level'] > 1)
{
    // Add ?
    if (isset($_POST['add_media']))
    {
        $error = '';

        // Supported medias
        $audio_ext = array('.mp3', '.MP3');
        $image_ext = array('.gif', '.GIF', '.jpg', '.JPG', '.jpeg', '.JPEG', '.png', '.PNG');
        $video_ext = array('.flv', '.FLV');

        // Format media name
        $patterns = array('`[^a-zA-Z0-9-_.\s]`', '`\s+`');
        $replacements = array(' ', '_');
        $media_name = strtolower(preg_replace($patterns, $replacements, $_FILES['media_file']['name']));
        $media_ext = substr($media_name, strrpos($media_name, '.'));

        // Check media
        if (!trim($media_name))
        {
            $error .= $lang['NO_MEDIA_FILE'];
        }
        else
        {
            // Sort media
            $media_dir = './../medias/';
            if (in_array($media_ext, $audio_ext))
            {
                $media_dir .= 'audio/';
            }
            elseif (in_array($media_ext, $image_ext))
            {
                $media_dir .= 'image/';
            }
            elseif (in_array($media_ext, $video_ext))
            {
                $media_dir .= 'video/';
            }
            else
            {
                $error .= $lang['INVALID_MEDIA_TYPE'];
            }
            $media_file = $media_dir . $media_name;
            // Check directory permissions
            if (!is_writable($media_dir))
            {
                $error .= sprintf($lang['ADMIN_MEDIAS_ERROR1'], $media_dir);
            }
            // Check duplicate media
            if (file_exists($media_file))
            {
                $error .= $lang['ADMIN_MEDIAS_ERROR2'];
            }
            // New name ?
            if (!empty($_POST['media_name']))
            {
                $media_name = strtolower(preg_replace($patterns, $replacements, $_POST['media_name']));
                $media_file = $media_dir . $media_name . $media_ext;
                $media_ext = substr($media_name, strrpos($media_name, '.'));
                if ((in_array($media_ext, $audio_ext)) ||
                    (in_array($media_ext, $image_ext)) ||
                    (in_array($media_ext, $video_ext)))
                {
                    $error .= $lang['ADMIN_MEDIAS_ERROR3'];
                }
            }
        }
        if ($error)
        {
            error_template($error);
        }
        else
        {
            if (move_uploaded_file($_FILES['media_file']['tmp_name'], $media_file))
            {
                success_template($lang['ADMIN_MEDIAS_ADDED'], './../admin/medias.php');
            }
            else
            {
                error_template($lang['ADMIN_MEDIAS_ERROR4']);
            }
        }
    }
    // Delete ?
    elseif (isset($_GET['action']) && $_GET['action'] == 'delete_media')
    {
        // Check query
        if (!empty($_GET['file']))
        {
            // Check media
            if (!is_file($_GET['file']))
            {
                error_template($lang['ADMIN_QUERY_ERROR']);
            }
            else
            {
                unlink($_GET['file']);
                success_template($lang['ADMIN_MEDIAS_DELETED'], './../admin/medias.php');
            }
        }
        else
        {
            error_template($lang['ADMIN_QUERY_ERROR']);
        }
    }
    // Add form
    else
    {
        $template->set_file('admin', 'admin/medias/add.htpl');
        $template->set_var(array('ADD' => $lang['ADD'],
                                 'ADMIN_MEDIAS_HEADER' => $lang['ADMIN_MEDIAS_HEADER'],
                                 'AUDIOS_LIST' => get_audios_list(),
                                 'BACK_ADMIN_INDEX' => $lang['BACK_ADMIN_INDEX'],
                                 'FORM_AUDIO' => $lang['FORM_AUDIO'],
                                 'FORM_IMAGE' => $lang['FORM_IMAGE'],
                                 'FORM_MEDIA_FILE' => $lang['FORM_MEDIA_FILE'],
                                 'FORM_MEDIA_NAME' => $lang['FORM_MEDIA_NAME'],
                                 'FORM_VIDEO' => $lang['FORM_VIDEO'],
                                 'IMAGES_LIST' => get_images_list(),
                                 'VIDEOS_LIST' => get_videos_list()));
        $template->parse('admin');
    }
}
// Other
else
{
    error_template($lang['ADMIN_LEVEL_ERROR']);
}

page_footer();

?>