<?php
// -----------------------------------------------------------------------
//
// $Id: register.php 151 2012-03-25 17:30:52Z raoul $
//
// Copyright (C) 2003-2012 Raoul Proena
// License: GNU GPL version 3 (see copying.txt file)
// Website: http://www.gnew.fr/
//
// -----------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// -----------------------------------------------------------------------

include('./../includes/common.php');

page_header($lang['USERS_REGISTER_TITLE']);

// Register function enabled ?
if ($settings['register_users'] == 0)
{
    error_template($lang['USERS_REGISTER_DISABLED']);
}
// User logged ?
elseif ($_SESSION['user_id'] != 0)
{
    error_template($lang['USERS_REGISTER_ERROR1']);
}
else
{
    // Account activation
    if (!empty($_GET['user_key']))
    {
        $sql->query('SELECT user_id
                     FROM ' . TABLE_USERS . '
                     WHERE user_key = \'' . $_GET['user_key'] . '\'
                     AND user_level = \'0\'');
        $table_users = $sql->fetch();
        // Check user
        if (!$table_users['user_id'])
        {
            error_template($lang['USERS_REGISTER_ERROR2']);
        }
        else
        {
            $sql->query('UPDATE ' . TABLE_USERS . '
                         SET user_key = \'0\', user_level = \'1\'
                         WHERE user_id = \'' . $table_users['user_id'] . '\'');
            success_template($lang['USERS_REGISTER_SUCCESS1'], './../index.php');
        }
    }
    // From register form
    elseif (isset($_POST['register']))
    {
        $error = '';
        $user_email = trim($_POST['user_email']);
        $user_name = chars2entities(trim($_POST['user_name']), ENT_QUOTES);
        $sql->query('SELECT user_email, user_name
                     FROM ' . TABLE_USERS . '
                     WHERE user_name = \'' . $user_name . '\'
                     OR user_email = \'' . $user_email . '\'');
        $table_users = $sql->fetch();
        // Check name
        if (!$user_name)
        {
            $error .= $lang['NO_USER_NAME'];
        }
        else
        {
            // Name too short ?
            if (strlen($_POST['user_name']) < $settings['min_usernames_length'])
            {
                $error .= sprintf($lang['USERS_REGISTER_ERROR3'], $settings['min_usernames_length']);
            }
            // Check duplicate name
            if ($user_name == $table_users['user_name'])
            {
                $error .= $lang['USERS_REGISTER_ERROR4'];
            }
        }
        // Check password
        if (!trim($_POST['user_password']))
        {
            $error .= $lang['NO_USER_PASSWORD'];
        }
        else
        {
            // Password too short ?
            if (strlen(trim($_POST['user_password'])) < $settings['min_passwords_length'])
            {
                $error .= sprintf($lang['USERS_REGISTER_ERROR5'], $settings['min_passwords_length']);
            }
            // Passwords ok ?
            if (trim($_POST['user_password2']) != trim($_POST['user_password']))
            {
                $error .= $lang['USERS_REGISTER_ERROR6'];
            }
        }
        // Check email
        if (!$user_email)
        {
            $error .= $lang['NO_USER_EMAIL'];
        }
        else
        {
            // Valid email ?
            if (check_email($user_email))
            {
                // Check duplicate email
                if ($user_email == $table_users['user_email'])
                {
                    $error .= $lang['USERS_REGISTER_ERROR7'];
                }
            }
            else
            {
                $error .= $lang['INVALID_USER_EMAIL'];
            }
        }
        if (!trim($_POST['user_date_format']))
        {
            $error .= $lang['NO_DATE_FORMAT'];
        }
        if (!preg_match('`^-?[0-9]{1,2}$`', $_POST['user_date_offset']))
        {
            $error .= $lang['NO_DATE_OFFSET'];
        }
        if ($_POST['user_captcha'] != $_SESSION['user_captcha'])
        {
            $error .= $lang['USERS_REGISTER_ERROR8'];
        }
        if ($error)
        {
            error_template($error);
        }
        else
        {
            $user_key = sha1(time() . $user_name);
            $sql->query('INSERT INTO ' . TABLE_USERS . ' (user_level, user_name, user_password, user_email, user_viewemail, user_website, user_location, user_occupation, user_day, user_month, user_year, user_creation, user_ip, user_language, user_template, user_date_format, user_date_offset, user_key)
                         VALUES (\'0\', \'' . $user_name . '\', \'' . sha1($_POST['user_password']) . '\', \'' . $user_email . '\', \'' . $_POST['user_viewemail'] . '\', \'' . $_POST['user_website'] . '\', \'' . chars2entities($_POST['user_location'], ENT_QUOTES) . '\', \'' . chars2entities($_POST['user_occupation'], ENT_QUOTES) . '\', \'' . $_POST['user_day'] . '\', \'' . $_POST['user_month'] . '\', \'' . $_POST['user_year'] . '\', \'' . time() . '\', \'' . $_SERVER['REMOTE_ADDR'] . '\', \'' . $_POST['user_language'] . '\', \'' . $_POST['user_template'] . '\', \'' . $_POST['user_date_format'] . '\', \'' . $_POST['user_date_offset'] . '\', \'' . $user_key . '\')');
            $subject = sprintf($lang['USERS_REGISTER_SUBJECT'], html_entity_decode($settings['sitename'], ENT_QUOTES, 'ISO-8859-1'));
            $message = sprintf($lang['USERS_REGISTER_MESSAGE'], html_entity_decode($user_name, ENT_QUOTES, 'ISO-8859-1'), html_entity_decode($settings['sitename'], ENT_QUOTES, 'ISO-8859-1'), $settings['siteurl'] . '/users/register.php?user_key=' . $user_key, html_entity_decode($settings['sender_name'], ENT_QUOTES, 'ISO-8859-1'));
            $header = 'From: ' . html_entity_decode($settings['sender_name'], ENT_QUOTES, 'ISO-8859-1') . ' <' . $settings['sender_email'] . '>' . "\n";
            $header .= 'Reply-To: ' . html_entity_decode($settings['sender_name'], ENT_QUOTES, 'ISO-8859-1') . ' <' . $settings['sender_email'] . '>' . "\n";
            $header .= 'X-Mailer: PHP/' . phpversion() . "\n";
            $header .= 'MIME-Version: 1.0' . "\n";
            $header .= 'Content-Type: text/plain; charset=iso-8859-1' . "\n";
            mail($user_email, $subject, $message, $header);
            success_template($lang['USERS_REGISTER_SUCCESS2'], './../index.php');
        }
    }
    // Register form
    else
    {
        $languages = get_languages_list();
        $templates = get_templates_list();
        $user_language_options = $user_template_options = '';
        $user_day_options = $user_month_options = $user_year_options = '';
        if ($settings['language_unique'] == 0)
        {
            for ($i = 0; $i < count($languages); $i++)
            {
                $user_language_options .= '<option value="' . $languages[$i] . '">' . $lang['' . strtoupper($languages[$i]) . ''] . '</option>';
            }
        }
        else
        {
            $user_language_options = '<option value="' . $settings['language'] . '">' . $lang['' . strtoupper($settings['language']) . ''] . '</option>';
        }
        if ($settings['template_unique'] == 0)
        {
            for ($i = 0; $i < count($templates); $i++)
            {
                $user_template_options .= '<option value="' . $templates[$i] . '">' . $templates[$i] . '</option>';
            }
        }
        else
        {
            $user_template_options = '<option value="' . $settings['template'] . '">' . $settings['template'] . '</option>';
        }
        for ($i = 1; $i <= 31; $i++)
        {
            $user_day_options .= '<option>' . $i . '</option>';
        }
        for ($j = 1; $j <= 12; $j++)
        {
            $user_month_options .= '<option>' . $j . '</option>';
        }
        for ($k = date('Y', time()); $k >= 1895; $k--)
        {
            $user_year_options .= '<option>' . $k . '</option>';
        }
        $template->set_file('register', 'users/register.htpl');
        $template->set_var(array('BACK_HOME' => $lang['BACK_HOME'],
                                 'DATE_FORMAT' => $settings['date_format'],
                                 'DATE_OFFSET' => $settings['date_offset'],
                                 'FORM_USER_BIRTHDAY' => $lang['FORM_USER_BIRTHDAY'],
                                 'FORM_USER_CAPTCHA' => $lang['FORM_USER_CAPTCHA'],
                                 'FORM_USER_DATE_FORMAT' => $lang['FORM_USER_DATE_FORMAT'],
                                 'FORM_USER_DATE_OFFSET' => $lang['FORM_USER_DATE_OFFSET'],
                                 'FORM_USER_DAY' => $lang['FORM_USER_DAY'],
                                 'FORM_USER_EMAIL' => $lang['FORM_USER_EMAIL'],
                                 'FORM_USER_LANGUAGE' => $lang['FORM_USER_LANGUAGE'],
                                 'FORM_USER_LOCATION' => $lang['FORM_USER_LOCATION'],
                                 'FORM_USER_MONTH' => $lang['FORM_USER_MONTH'],
                                 'FORM_USER_NAME' => $lang['FORM_USER_NAME'],
                                 'FORM_USER_OCCUPATION' => $lang['FORM_USER_OCCUPATION'],
                                 'FORM_USER_PASSWORD' => $lang['FORM_USER_PASSWORD'],
                                 'FORM_USER_PASSWORD2' => $lang['FORM_USER_PASSWORD2'],
                                 'FORM_USER_TEMPLATE' => $lang['FORM_USER_TEMPLATE'],
                                 'FORM_USER_VIEWEMAIL' => $lang['FORM_USER_VIEWEMAIL'],
                                 'FORM_USER_WEBSITE' => $lang['FORM_USER_WEBSITE'],
                                 'FORM_USER_YEAR' => $lang['FORM_USER_YEAR'],
                                 'NO' => $lang['NO'],
                                 'REGISTER' => $lang['REGISTER'],
                                 'USER_CAPTCHA' => '<img src="./../users/captcha.php" alt="CAPTCHA" />',
                                 'USER_DAY_OPTIONS' => $user_day_options,
                                 'USER_LANGUAGE_OPTIONS' => $user_language_options,
                                 'USER_MONTH_OPTIONS' => $user_month_options,
                                 'USER_TEMPLATE_OPTIONS' => $user_template_options,
                                 'USER_YEAR_OPTIONS' => $user_year_options,
                                 'USERS_REGISTER_HEADER' => $lang['USERS_REGISTER_HEADER'],
                                 'YES' => $lang['YES']));
        $template->parse('register');
    }
}

page_footer();

?>